Flask-Social
============

Oauth provider login and APIs for use with 
`Flask-Security <http://packages.python.org/Flask-Security/>`_

Resources
---------

- `Documentation <http://packages.python.org/Flask-Social/>`_
- `Issue Tracker <http://github.com/mattupstate/flask-social/issues>`_
- `Code <http://github.com/mattupstate/flask-social/>`_
- `Development Version
  <http://github.com/mattupstate/flask-rq/zipball/develop#egg=Flask-Social-dev>`_
- `Example Application <http://flask-social-example.herokuapp.com/>`_